package com.example.demo.controllers

import com.example.demo.entities.User
import jakarta.validation.Valid
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

@RestController
class UsersController {
    @GetMapping("/users")
    fun index(): List<User> {
        return User.listAll()
    }

    @GetMapping("/users/{id}")
    fun show(@PathVariable id: Long): User? {
        return User.findById(id)
    }

    @PostMapping("/users")
    fun create(@Valid @RequestBody newUser: User): ResponseEntity<User> {
        newUser.persistAndFlush()
        return ResponseEntity(newUser, HttpStatus.CREATED)
    }

    @PatchMapping("/users/{id}")
    fun update(@PathVariable id: Long, @Valid @RequestBody user: User): ResponseEntity<User> {
        user.persist()
        return ResponseEntity(user, HttpStatus.OK)
    }

    @DeleteMapping("/users/{id}")
    fun destroy(@PathVariable id: Long) {
        User.deleteById(id)
    }
}
